==> haskell-asn1-encoding-0.9.5-8-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
key: asn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: fbae9699998416a956d32b62d131c26f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/asn1-encoding-0.9.5
data-dir: /usr/share/i386-linux-ghc-8.0.1/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-4zuNY5dpyCgHGZJcXAJva4
depends:
    asn1-types-0.3.2-KYu7pQLyIazKugAPAWEtdg base-4.9.0.0
    bytestring-0.10.8.1 hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.5-13-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-encoding
version: 0.9.5
id: asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
key: asn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1
synopsis: ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.ASN1.Error Data.ASN1.BinaryEncoding
    Data.ASN1.BinaryEncoding.Raw Data.ASN1.Encoding Data.ASN1.Stream
    Data.ASN1.Object
hidden-modules: Data.ASN1.Prim Data.ASN1.BinaryEncoding.Parse
                Data.ASN1.BinaryEncoding.Writer Data.ASN1.Internal
                Data.ASN1.Serialize Data.ASN1.Get
abi: 2527340eb0c8b7a0ca17a4f29233752e
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/asn1-encoding-0.9.5
library-dirs: /usr/lib/ghc-8.0.2/site-local/asn1-encoding-0.9.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/asn1-encoding-0.9.5
hs-libraries: HSasn1-encoding-0.9.5-IYQwkkfu141LtkpgWZ9ola
depends:
    asn1-types-0.3.2-9aXDFyarEaR4iFeC6pBR3x base-4.9.1.0
    bytestring-0.10.8.1 hourglass-0.2.10-pnbvWmzfcY1rOFETQEmcY
haddock-interfaces: /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock
haddock-html: /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
